---
title: Filtering
page_title: Filtering - DropDownTree - Kendo UI for Vue
description: "Filter the displayed items of the Kendo UI DropDownTree wrapper for Vue."
slug: filtering_dropdowntree
position: 3
---

# Filtering

The built-in filtering functionality enables the user to filter the displayed DropDownTree items by their text value.

By default, filtering is disabled and can be performed over `string` values only&mdash;that is, either the widget data has to be an array of strings or configured in the `data-text-field` option over the field.

The DropDownTree supports the following filter values:

* `startswith`
* `endswith`
* `contains`

The following example demonstrates how to enable the `startsWith filtering` within the DropDownTree.

```html-preview
<div id="vueapp" class="vue-app">
    <kendo-dropdowntree :data-source="localDataSource"
                        :filter="'startswith'"
                        :placeholder="'Select ...'"
                        style="width: 300px;">
    </kendo-dropdowntree>
</div>
```
```js
Vue.use(DropDownTreeInstaller);

new Vue({
    el: "#vueapp",
    data: function() {
        return {
            localDataSource: new kendo.data.HierarchicalDataSource({
                data: [{
                    text: 'Furniture',
                    items: [
                        { text: 'Tables & Chairs' },
                        { text: 'Sofas' },
                        { text: 'Occasional Furniture' }
                    ]
                },{
                    text: 'Decor',
                    items: [
                        { text: 'Bed Linen' },
                        { text: 'Curtains & Blinds' },
                        { text: 'Carpets' }
                    ]
                }]
            })
        }
    }
})
```

## Suggested Links

* [Kendo UI DropDownTree for jQuery](https://docs.telerik.com/kendo-ui/controls/editors/dropdowntree/overview)
* [API Reference of the DropDownTree Widget](https://docs.telerik.com/kendo-ui/api/javascript/ui/dropdowntree)
